@@ -3,7 +3,8 @@
 import json
 from requests import Response, Session, Request
 from pg_python_sdk.payment_gateway_response import PaymentGatewayResponse
-
+import urllib3
+urllib3.disable_warnings()
 
 class PaymentGatewayRequest:
 
@@ -14,7 +15,7 @@ class PaymentGatewayRequest:
         _session = Session()
         _request = Request(
             method,
-            f'https://134.122.118.178/api/v1/{uri}',
+            f'https://payment-gateway.hager-bet.com/api/v1/{uri}',
             data=json.dumps(data),
             headers={
                 'Authorization': f'Bearer {self.key}',
@@ -24,7 +25,7 @@ class PaymentGatewayRequest:
 
         _prepared = _request.prepare()
         _response = _session.send(
-            _prepared,  allow_redirects=False)
+            _prepared, verify=True, allow_redirects=False)
 
         return _response
 
